@@ -15,6 +15,9 @@ class MyForm(QtGui.QMainWindow):
 		QtCore.QObject.connect(self.ui.btnSendMessages, QtCore.SIGNAL('clicked()'), self.queueMessages)
 		self.maintimer = QtCore.QTimer(self);
 		self.connect(self.maintimer, QtCore.SIGNAL('timeout()'), self.processMessages)
+		# Add items to the combo box.
+		#self.cmbAccount=QComboBox(FALSE, row1)
+		self.ui.cmbAccount.addItems(["Google Voice - QGVDial", "SIM"])
 		
 	def queueMessages(self):
 		if self.running:
@@ -32,9 +35,14 @@ class MyForm(QtGui.QMainWindow):
 			self.message = str(self.ui.txtMessage.text())
 			self.delay = int(self.ui.txtDelay.text())
 			self.repetitions = int(self.ui.txtRepetitions.text())
-			self.sendMessage("GV")
-			self.ui.btnSendMessages.setText("Stop (1 of " + str(self.repetitions) + ")")
-			self.maintimer.start(self.delay * 1000)
+			self.method = self.ui.cmbAccount.currentIndex()
+			if self.repetitions >= 1:
+				self.sendMessage(self.method)
+			if self.repetitions > 1:
+				self.ui.btnSendMessages.setText("Stop (1 of " + str(self.repetitions) + ")")
+				self.maintimer.start(self.delay * 1000)
+			if self.repetitions <= 1:
+				self.running = False
 		
 	def processMessages(self):
 		"""Send Queued Messages as needed"""
@@ -42,7 +50,7 @@ class MyForm(QtGui.QMainWindow):
 			print "Counter: " + str(self.counter)
 			print "Delay: " + str(self.delay)
 			print "Repetitions: " + str(self.repetitions)
-			self.sendMessage("GV")
+			self.sendMessage(self.method)
 			self.counter=self.counter+1
 			self.ui.btnSendMessages.setText("Stop (" + str(self.counter) + " of " + str(self.repetitions) + ")")
 			if (self.counter >= self.repetitions):
@@ -52,8 +60,12 @@ class MyForm(QtGui.QMainWindow):
 		
 	def sendMessage(self, method):
 		"""Send message using defined method (GV, SMS, etc)"""
-		if method == "GV":
-			os.system('dbus-send --dest=org.QGVDial.TextServer --session --print-reply /org/QGVDial/TextServer org.QGVDial.TextServer.Text array:string:"+1' + self.number + '" string:"' + self.message + '"')
+		if method == 0: # Google Voice
+			# Import to use proper python sending technique
+			os.system('dbus-send --dest=org.QGVDial.TextServer --session --print-reply /org/QGVDial/TextServer org.QGVDial.TextServer.Text array:string:"' + self.number + '" string:"' + self.message + '"')
+		elif method == 1: # SIM
+			os.system('/usr/bin/smssend -n ' + self.number + ' -m "' + self.message + '"')
+			#print "SIM message sending not yet supported."
 		else:
 			print "Message sending method not recognized."
 		
